%global srcname     lumina
%global srcurl      https://github.com/trueos/%{srcname}
%global beta        Beta2
%global use_beta    1

# Enable pulling translations, split into separate project
%bcond_with         pull_translations

Summary:            A lightweight, portable desktop environment
Name:               %{srcname}-desktop
Version:            1.0.0
%if 0%{?use_beta}
Release:            0.1.%{beta}%{?dist}
%else
Release:            1%{?dist}
%endif
License:            BSD
URL:                http://%{name}.org
Group:              User Interface/Desktops

# Main source
%if 0%{?use_beta}
Source0:            %{srcurl}/archive/v%{version}-%{beta}.tar.gz#/%{name}-%{version}-%{beta}.tar.gz
%else
Source0:            %{srcurl}/archive/v%{version}-Release/%{srcname}-%{version}-Release.tar.gz
%endif
%if %{with pull_translations}
# Translations
Source1:            %{srcurl}-i18n/raw/master/dist/%{srcname}-i18n.txz
%endif

# Exclude IBM ESA/390 and ESA System/z architectures
ExcludeArch:        s390 s390x

# Compiler requirements
BuildRequires:      gcc, gcc-c++

%if %{with pull_translations}
# Translation installation requirements
BuildRequires:      tar
%endif

# Qt requirements
BuildRequires:      qt5-qttools, qt5-qttools-devel, qt5-linguist
BuildRequires:      qt5-qtbase-devel, qt5-qtmultimedia-devel, qt5-qtdeclarative-devel
BuildRequires:      qt5-qtsvg-devel, qt5-qtx11extras-devel

# X component requirements
BuildRequires:      xcb-util-image, xcb-util-image-devel, xcb-util-wm-devel, libxcb-devel, xcb-util-devel
BuildRequires:      libXcomposite-devel, libXdamage-devel, libXrender-devel

BuildRequires:      desktop-file-utils

# Runtime requirements
Requires:           alsa-utils%{?_isa}, acpi%{?_isa}, numlockx%{?_isa}
Requires:           pavucontrol%{?_isa}, sysstat%{?_isa}
Requires:           xscreensaver%{?_isa}, xbacklight%{?_isa}, xterm%{?_isa}
Requires:           qt5-style-oxygen%{?_isa}, plasma-oxygen%{?_isa}
Requires:           fluxbox%{?_isa}

# Enforce the library subpackage version requirement
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}
Requires:           %{name}-data = %{version}-%{release}

# Desktop requirements
%if 0%{?fedora} >= 23
Suggests:           %{srcname}-wallpapers = %{version}-%{release}
Suggests:           %{srcname}-open%{?_isa} = %{version}-%{release}
Suggests:           %{srcname}-config%{?_isa} = %{version}-%{release}
Suggests:           %{srcname}-fm%{?_isa} = %{version}-%{release}
Suggests:           %{srcname}-screenshot%{?_isa} = %{version}-%{release}
Suggests:           %{srcname}-search%{?_isa} = %{version}-%{release}
Suggests:           %{srcname}-info%{?_isa} = %{version}-%{release}
Suggests:           %{srcname}-xconfig%{?_isa} = %{version}-%{release}
Suggests:           %{srcname}-fileinfo%{?_isa} = %{version}-%{release}
Suggests:           %{srcname}-textedit%{?_isa} = %{version}-%{release}
%endif

%description
The Lumina Desktop Environment is a lightweight system interface
that is designed for use on any Unix-like operating system.

%package data
Summary:            Data for Lumina Desktop
Group:              System Environment/Libraries
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}

%description data
This package provides the data files for the Lumina Desktop
Environment: Colors, desktop background, theme templates.

%package libs
Summary:            Libraries for Lumina Desktop
Group:              System Environment/Libraries

%description libs
This package provides the libraries for the Lumina Desktop
Environment.

%package devel
Summary:            Development libraries for Lumina Desktop
Group:              Development/Libraries
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
This package provides the files needed to develop plugins
or extensions for the Lumina Desktop Environment, or
to develop applications that use Lumina Desktop libraries.

%package wallpapers
Summary:            Wallpapers for Lumina Desktop
BuildArch:          noarch
Requires:           kde-filesystem

%description wallpapers
Optional wallpapers recommended for Lumina Desktop.

%package -n %{srcname}-open
Summary:            xdg-open style utility for Lumina Desktop
Group:              User Interface/Desktops
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description -n %{srcname}-open
This package provides %{srcname}-open, which handles opening of
files and URLs according to the system-wide mimetype association.
It also provides an optional selector if more than one application
is assigned with the given url or file type.

%package -n %{srcname}-config
Summary:            Configuration utility for Lumina Desktop
Group:              User Interface/Desktops
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description -n %{srcname}-config
This package provides %{srcname}-config, which allows changing
various aspects of %{srcname} and fluxbox, like the wallpaper being
used, theme, icons, panel (and plugins), startup and default
applications, desktop menu and more.

%package -n %{srcname}-fm
Summary:            File manager for Lumina Desktop
Group:              User Interface/Desktops
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description -n %{srcname}-fm
This package provides %{srcname}-fm, which is a simple file manager
with support for multiple view modes, tabbed browsing,
including an integrated slideshow-based picture viewer.


%package -n %{srcname}-screenshot
Summary:            Screenshot utility for Lumina Desktop
Group:              User Interface/Desktops
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description -n %{srcname}-screenshot
This package provides %{srcname}-screenshot, which is a simple
screenshot utility that allows to snapshot the whole desktop
or a single window after a configurable delay.

Optionally the window border can be hidden when taking a
screenshot of a single window.


%package -n %{srcname}-search
Summary:            Search utility for Lumina Desktop
Group:              User Interface/Desktops
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description -n %{srcname}-search
This package provides %{srcname}-search, which is a simple
search utility that allows to search for applications or
files and directories in the home directory and launch
or open them.


%package -n %{srcname}-info
Summary:            Basic information utility for Lumina Desktop
Group:              User Interface/Desktops
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description -n %{srcname}-info
This package provides %{srcname}-info, which is a simple
utility that displays various information about the Lumina
installation, like paths, contributors, license or version.


%package -n %{srcname}-xconfig
Summary:            X server display configuration tool for Lumina Desktop
Group:              User Interface/Desktops
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description -n %{srcname}-xconfig
This package provides %{srcname}-xconfig, which is a simple
multi-head aware display configuration tool for configuring
the X server.


%package -n %{srcname}-fileinfo
Summary:            Desktop file editor for Lumina Desktop
Group:              User Interface/Desktops
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description -n %{srcname}-fileinfo
This package provides %{srcname}-fileinfo, which is an
advanced desktop file (menu) editor.


%package -n %{srcname}-textedit
Summary:            Text file editor for Lumina Desktop
Group:              User Interface/Desktops
Requires:           %{name}-libs%{?_isa} = %{version}-%{release}

%description -n %{srcname}-textedit
This package provides %{srcname}-textedit, which is an
text file editor.

########################################################################################
%prep
%if 0%{?use_beta}
%setup -qn%{srcname}-%{version}-%{beta}
%else
%setup -q -n %{srcname}-%{version}-Release
%endif
# bug with make -C
sed -i -r -e '/cp defaults\//d' -e 's:(INSTALLS.*)defaults:\1:' \
 src-qt5/core/%{srcname}-desktop/*.pro

%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
%qmake_qt5 ../*.pro \
 CONFIG+=configure \
 LIBPREFIX="%{_libdir}" \
 L_BINDIR="%{_bindir}" \
 L_LIBDIR=%{_libdir} \
 L_SHAREDIR=%{_datadir} \
 L_ETCDIR=%{_sysconfdir} \
 L_INCLUDEDIR=%{_includedir} \
 QT5LIBDIR="%{_qt5_prefix}"
popd
%make_build -C %{_target_platform}

%install
# Install the desktop
%make_install -C %{_target_platform} INSTALL_ROOT=%{buildroot}

%if %{with pull_translations}
# Install translations
mkdir -p %{buildroot}%{_datadir}/Lumina-DE/i18n
tar xvf %{SOURCE1} -C %{buildroot}%{_datadir}/Lumina-DE/i18n
%endif

# Move config folder to correct location
install -m0644 -D src-qt5/core/%{name}/defaults/%{srcname}Desktop.conf \
 -t %{buildroot}%{_sysconfdir}
# Other missing files in cmake installation
install -m0644 -D src-qt5/core/%{name}/defaults/desktop-background.jpg \
 -t %{buildroot}%{_datadir}/%{name}

# Fix paths in desktop files
find %{buildroot}%{_datadir}/applications -name *.desktop -print -exec \
 desktop-file-edit --remove-only-show-in=Lumina --add-only-show-in=X-Lumina '{}' \;
desktop-file-edit --remove-key=Categories \
 %{buildroot}%{_datadir}/applications/%{srcname}-support.desktop

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{srcname}-*.desktop

########################################################################################
%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%post -n %{srcname}-fm
/usr/bin/update-desktop-database &> /dev/null || :

%postun -n %{srcname}-fm
/usr/bin/update-desktop-database &> /dev/null || :

%post -n %{srcname}-textedit
/usr/bin/update-desktop-database &> /dev/null || :

%postun -n %{srcname}-textedit
/usr/bin/update-desktop-database &> /dev/null || :

########################################################################################
%files
%{_bindir}/lte
%{_bindir}/%{name}
%{_bindir}/start-%{name}
%config(noreplace) %{_sysconfdir}/%{srcname}Desktop.conf
%{_datadir}/pixmaps/Lumina-DE.png
%{_datadir}/xsessions/Lumina-DE.desktop
%{_datadir}/applications/%{srcname}-support.desktop

%files data
%{_datadir}/%{name}/

%files libs
%license LICENSE
%{_libdir}/libLuminaUtils.so.*

%files devel
%license LICENSE
%{_libdir}/libLuminaUtils.so
%{_includedir}/Lumina*.h

%files wallpapers
%license LICENSE
%{_datadir}/wallpapers/Lumina-DE/

%files -n %{srcname}-open
%{_bindir}/%{srcname}-open

%files -n %{srcname}-config
%{_bindir}/%{srcname}-config
%{_datadir}/applications/%{srcname}-config.desktop

%files -n %{srcname}-fm
%{_bindir}/%{srcname}-fm
%{_datadir}/pixmaps/Insight-FileManager.png
%{_datadir}/applications/%{srcname}-fm.desktop

%files -n %{srcname}-screenshot
%{_bindir}/%{srcname}-screenshot
%{_datadir}/applications/%{srcname}-screenshot.desktop

%files -n %{srcname}-search
%{_bindir}/%{srcname}-search
%{_datadir}/applications/%{srcname}-search.desktop

%files -n %{srcname}-info
%license src-qt5/core/%{srcname}-info/LICENSE
%{_bindir}/%{srcname}-info
%{_datadir}/applications/%{srcname}-info.desktop

%files -n %{srcname}-xconfig
%{_bindir}/%{srcname}-xconfig
%{_datadir}/applications/%{srcname}-xconfig.desktop

%files -n %{srcname}-fileinfo
%{_bindir}/%{srcname}-fileinfo
%{_datadir}/applications/%{srcname}-fileinfo.desktop

%files -n %{srcname}-textedit
%{_bindir}/%{srcname}-textedit
%{_datadir}/applications/%{srcname}-textedit.desktop

########################################################################################
%changelog
* Fri Jul 15 2016 Raphael Groner <projects.rg@smart.ms> - 1.0.0-0.1.Beta2
- version 1.0.0 Beta2
- prepare for review
- split more subpackages: i18n, wallpapers

* Wed Dec 23 2015 Neal Gompa <ngompa13@gmail.com>
- Update to 0.8.8
- Bring it closer to Fedora guidelines
- Break out Lumina Desktop package into subpackages
- Unify 32-bit and 64-bit packaging

* Tue Oct 27 2015 Jesse Smith <jsmith@resonatingmedia.com>
- Update to 0.8.7

* Thu Aug 20 2015 Jesse Smith <jsmith@resonatingmedia.com>
- Updated for 32-bit

* Thu Jul 30 2015 Jesse Smith <jsmith@resonatingmedia.com>
- Initial build
